
<!--
FrozenIsBool False
-->

#Classor

##Doc
----


> 
> The Classor Module defines the ClassorClass 
> class, which is the deepest parent class in the framework for decorating another class. For each decorated class, 
> it just sets up the NameStr in it and also a KeyStrsList for accumulating the new KeyStrs from 
> other attributes that can be provided by other decorating Classes.
> 
> 

----

<small>
View the Classor notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Classor.ipynb)
</small>

